<?php

class DHWC_Layout {
	public function __construct(){
		add_action( 'plugins_loaded', array($this,'plugins_loaded'));
	}
	
	public function plugins_loaded(){
		if(!function_exists('is_plugin_active'))
			include_once( ABSPATH . 'wp-admin/includes/plugin.php' ); // Require plugin.php to use is_plugin_active() below
		
		if ( !is_plugin_active( 'woocommerce/woocommerce.php' )) {
			add_action('admin_notices', array($this,'woocommerce_notice'));
			return ;
		}
		
		load_plugin_textdomain( DHVC_WOO, false, basename(DHVC_WOO_DIR) . '/languages' );
		
		$this->_includes();
		
		$this->_init();
	}
	
	private function _init(){
		//Ajax quickview
		add_action( 'wp_ajax_dhvc_woo_product_quickview', array( &$this, 'quickview' ) );
		add_action( 'wp_ajax_nopriv_dhvc_woo_product_quickview', array( &$this, 'quickview' ) );
		//bar menu
		add_action( 'admin_bar_menu', array(__CLASS__,'admin_bar_menu'), 1000 );
	}
	
	public static function admin_bar_menu($wp_admin_bar){
		if ( is_shop()) {
			$wp_admin_bar->add_menu( array(
				'id' => 'wp-admin-bar-edit',
				'title' => __( 'Edit Shop Page', DHVC_WOO ),
				'href' => get_edit_post_link(wc_get_page_id('shop'))
			) );
		}
	}
	
	public function woocommerce_notice(){
		$plugin = get_plugin_data(__FILE__);
		echo '<div class="updated">
			    <p>' . sprintf(__('<strong>%s</strong> requires <strong><a href="http://www.woothemes.com/woocommerce/" target="_blank">WooCommerce</a></strong> plugin to be installed and activated on your site.', DHVC_WOO), $plugin['Name']) . '</p>
			  </div>';
	}
	
	private function _includes(){
		
		include_once DHVC_WOO_DIR.'/includes/functions.php';
		include_once DHVC_WOO_DIR.'/includes/class-dhwc-layout-shortcode.php';
		
		//DHWC Brand
		include_once DHVC_WOO_DIR.'/includes/dhwc-brand/dhwc-brand.php';
		
		if(defined('WPB_VC_VERSION')){
			include_once DHVC_WOO_DIR.'/includes/class-dhwc-layout-vc.php';
		}
		
		if(is_admin()){
			include_once DHVC_WOO_DIR.'/includes/class-dhwc-layout-admin.php';
		}else{
			include_once DHVC_WOO_DIR.'/includes/class-dhwc-layout-frontend.php';
		}
	}
	
	public function quickview(){
		global $post, $product;
		
		$product_id = isset($_POST['product_id']) ? (int) $_POST['product_id'] : 0;
		
		// set the main wp query for the product
		$product = wc_get_product($product_id);
		$post = get_post($product_id);
		setup_postdata($post);
		
		ob_start();
		do_action('dhwc_layout_product_quickview_before');
		dhwc_layout_get_template('quickview.php');
		do_action('dhwc_layout_product_quickview_after');
		$output = ob_get_clean();
		$output = apply_filters('dhvc_woo_product_quickview_html', $output);
		echo trim($output);
		wp_reset_postdata();
		die();
	}
	
}

new DHWC_Layout();